# bioutil 0.0.6 (2020-05-31)
Add some new features to sequtil.py

# biotuil 0.0.5 (2020-05-28)
Fixed some minor bugs, and add a path.get_path function to return abusolute path of inputs.

# bioutil 0.0.4 (2020-05-27)
add sequtil.seqmodify.break_fasta function.

# bioutil 0.0.3 (2020-05-26)
make path.realpth can deal many paths at one time.

# bioutil 0.0.2
## fixed system module subprocess import error in some functions


# bioutil 0.0.1
## biology related operations in bioinformatics
### 1.system
this module include linux system related operations functions
### 2.sequtil
this module include sequnces file operations functions, e.g. fasta/q operations
### 3.bamutil
this module include bam operations e.g index bam, sort bam, retrieve reads from bam.


